You are viewing a plain text version of this content. The canonical link for it is here.
Posted to dev@commons.apache.org by ra...@apache.org on 2006/02/05 08:20:38 UTC

svn commit: r374977 - /jakarta/commons/sandbox/scxml/branches/STATELESS_MODEL/src/main/java/org/apache/commons/scxml/SCInstance.java

Author: rahul
Date: Sat Feb  4 23:20:37 2006
New Revision: 374977

URL: http://svn.apache.org/viewcvs?rev=374977&view=rev
Log:
Match code to new class name. Needs better Javadocs, coming soon.

Modified:
    jakarta/commons/sandbox/scxml/branches/STATELESS_MODEL/src/main/java/org/apache/commons/scxml/SCInstance.java

Modified: jakarta/commons/sandbox/scxml/branches/STATELESS_MODEL/src/main/java/org/apache/commons/scxml/SCInstance.java
URL: http://svn.apache.org/viewcvs/jakarta/commons/sandbox/scxml/branches/STATELESS_MODEL/src/main/java/org/apache/commons/scxml/SCInstance.java?rev=374977&r1=374976&r2=374977&view=diff
==============================================================================
--- jakarta/commons/sandbox/scxml/branches/STATELESS_MODEL/src/main/java/org/apache/commons/scxml/SCInstance.java (original)
+++ jakarta/commons/sandbox/scxml/branches/STATELESS_MODEL/src/main/java/org/apache/commons/scxml/SCInstance.java Sat Feb  4 23:20:37 2006
@@ -26,11 +26,11 @@
 import org.apache.commons.scxml.model.TransitionTarget;
 
 /**
  * The <code>Registry</code> performs book-keeping functions for
  * a particular execution of a state machine represented by the
  * a <code>SCXML</code> object.
  */
-public class Registry {
+public class SCInstance {
 
     /**
      * The notification registry.
@@ -62,7 +62,7 @@
     /**
      * Constructor.
      */
-    Registry() {
+    SCInstance() {
         this.notificationRegistry = new NotificationRegistry();
         this.contexts = new HashMap();
         this.histories = new HashMap();



---------------------------------------------------------------------
@@ -26,11 +26,11 @@
 
 /**
- * The <code>Registry</code> performs book-keeping functions for
- * a particular execution of a state machine represented by the
- * a <code>SCXML</code> object.
+ * The <code>SCInstance</code> performs book-keeping functions for
+ * a particular execution of a state chart represented by a
+ * <code>SCXML</code> object.
  */
To unsubscribe, e-mail: commons-dev-unsubscribe@jakarta.apache.org
For additional commands, e-mail: commons-dev-help@jakarta.apache.org